package com.datacloudsec.scan.service.impl;

import com.datacloudsec.annotations.Transactional;
import com.datacloudsec.exception.UEException;
import com.datacloudsec.scan.common.Constant;
import com.datacloudsec.scan.dao.DeviceGroupMapper;
import com.datacloudsec.scan.dao.DeviceMapper;
import com.datacloudsec.scan.dao.EngineMapper;
import com.datacloudsec.scan.dao.LogMapper;
import com.datacloudsec.scan.dao.PwdMapper;
import com.datacloudsec.scan.dao.PwddicMapper;
import com.datacloudsec.scan.dao.SysBugMapper;
import com.datacloudsec.scan.dao.TaskMapper;
import com.datacloudsec.scan.entity.LicCmp;
import com.datacloudsec.scan.entity.Task;
import com.datacloudsec.scan.entity.User;
import com.datacloudsec.scan.service.IEngine;
import com.datacloudsec.scan.service.IPwd;
import com.datacloudsec.scan.tasks.InitSystemTask;
import com.datacloudsec.scan.tasks.scheduler.job.AlermJob;
import com.datacloudsec.utils.ComonZipUtil;
import com.datacloudsec.utils.DataRule;
import com.datacloudsec.utils.EntryResult;
import com.datacloudsec.utils.IPUtil;
import com.datacloudsec.utils.InstanceUtil;
import com.datacloudsec.utils.JbossDecryptor;
import com.datacloudsec.utils.JsonUtil;
import com.datacloudsec.utils.MybatisUtil;
import com.datacloudsec.utils.ObjectUtil;
import com.datacloudsec.utils.PoiExcelUtils;
import com.datacloudsec.utils.SerializeUtil;
import com.datacloudsec.utils.SftpDownloader;
import com.datacloudsec.utils.WebLogicPwdDecryptor;
import com.datacloudsec.utils.XmlUtils;
import com.datacloudsec.utils.ZipUtil;
import com.fasterxml.jackson.core.type.TypeReference;
import com.google.common.collect.Sets;
import java.io.File;
import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import javax.servlet.http.HttpSession;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.collections4.MapUtils;
import org.apache.commons.io.FileUtils;
import org.apache.commons.io.IOUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.ibatis.session.SqlSession;
import org.apache.log4j.Logger;
import org.dom4j.DocumentHelper;
import org.dom4j.Element;

/* loaded from: com_datacloudsec_scan_service_impl.jar:com/datacloudsec/scan/service/impl/PwdService.class */
public class PwdService extends TaskBaseService implements IPwd {
    private PwdMapper pwdMapper = (PwdMapper) InstanceUtil.newDaoInstance(PwdMapper.class);
    private IEngine engine = new EngineService();
    private SysBugMapper sysBugMapper = (SysBugMapper) InstanceUtil.newDaoInstance(SysBugMapper.class);
    private DeviceMapper deviceMapper = (DeviceMapper) InstanceUtil.newDaoInstance(DeviceMapper.class);
    private DeviceGroupMapper deviceGroupMapper = (DeviceGroupMapper) InstanceUtil.newDaoInstance(DeviceGroupMapper.class);
    private PwddicMapper pwddicMapper = (PwddicMapper) InstanceUtil.newDaoInstance(PwddicMapper.class);
    private EngineMapper engineMapper = (EngineMapper) InstanceUtil.newDaoInstance(EngineMapper.class);
    private LogMapper logMapper = (LogMapper) InstanceUtil.newDaoInstance(LogMapper.class);
    private Logger LOG = Logger.getLogger(PwdService.class);
    public static final String ORACLE_USER = "SYS|SYSTEM|OUTLN|DIP|ORACLE_OCM|DBSNMP|APPQOSSYS|WMSYS|XS$NULL|EXFSYS|CTXSYS|XDB|OLAPSYS|ORDSYS|ORDDATA|ORDPLUGINS|SI_INFORMTN_SCHEMA|MDSYS|MDDATA|SPATIAL_WFS_ADMIN_USR|WFS_USR_ROLE|SPATIAL_CSW_ADMIN|SPATIAL_CSW_ADMIN_USR|CSW_USR_ROLE|SYSMAN|MGMT_VIEW|FLOWS_FILES|APEX_PUBLIC_USER|APEX_030200|OWBSYS|OWB$CLIENT|OWBSYS_AUDIT|SCOTT|HR|OE|IX|SH|PM|BI";

    public Map<String, List<Map<String, Object>>> queryTaskDevs(HttpSession session) throws Exception {
        String rule = DataRule.getRuleWhere(session, "t_task");
        List<Map<String, Object>> list = this.pwdMapper.queryTaskDevs(rule);
        return EntryResult.parseEntryListMap(list, "name");
    }

    public void impOfflinePwd(Object uniqname, Integer devid) throws Exception {
        File pwddicFile;
        Task task = this.pwdMapper.getTaskBydevId(devid);
        Map<String, Object> confMap = (Map) JsonUtil.MAPPER.readValue(ObjectUtil.getString(task.getConfContent(), "{}"), new TypeReference<Map<String, Object>>() { // from class: com.datacloudsec.scan.service.impl.PwdService.1
        });
        Map<String, Object> pwddic = this.pwddicMapper.getTemplateById(ObjectUtil.getInt(confMap.get("passwords")));
        String pwddicPath = ObjectUtil.getString(pwddic.get("path"), (String) null);
        if (pwddicPath == null) {
            pwddicFile = new File(Constant.TEMP_DIR, String.valueOf(System.nanoTime()) + ".txt");
            FileUtils.writeStringToFile(pwddicFile, ObjectUtil.getString(pwddic.get("content"), "").replace("|", "\n"));
        } else {
            pwddicFile = new File(Constant.PWDDIC_DIC, pwddicPath);
        }
        if (uniqname instanceof List) {
            for (String uname : (List) uniqname) {
                offlineCheck(uname, pwddicFile, null, devid);
            }
        } else {
            offlineCheck(ObjectUtil.getString(uniqname, ""), pwddicFile, null, devid);
        }
        Map<String, Object> device = this.pwdMapper.getTaskDevById(devid);
        String confContent = ObjectUtil.getString(device.get("confContent"), "");
        if (StringUtils.isNotBlank(confContent) && confContent.contains("offPwdFile")) {
            Map<String, Object> confContentMap = (Map) JsonUtil.MAPPER.readValue(confContent, HashMap.class);
            for (Map.Entry<String, Object> conf : confContentMap.entrySet()) {
                if (conf.getValue() instanceof Map) {
                    downloadPwdFile((Map) conf.getValue(), conf, ObjectUtil.getString(device.get("ip"), ""), pwddicFile, null, devid);
                } else {
                    List<Map<String, Object>> confList = (List) conf.getValue();
                    for (Map<String, Object> c : confList) {
                        downloadPwdFile(c, conf, ObjectUtil.getString(device.get("ip"), ""), pwddicFile, null, devid);
                    }
                }
            }
        }
        Integer pwdCount = this.sysBugMapper.pwdCountByDev(devid);
        this.sysBugMapper.insertPwdStatics(pwdCount, new Date(), devid);
        Integer pwdStaCount = this.sysBugMapper.pwdStaCount();
        if (pwdStaCount != null && pwdStaCount.intValue() > 7) {
            this.sysBugMapper.delPwdStaOneWeek();
        }
    }

    private void downloadPwdFile(Map<String, Object> c, Map.Entry<String, Object> conf, String ip, File pwddicFile, List<Map<String, Object>> pwdList, Integer devid) throws Exception {
        String offPwdFiles = ObjectUtil.getString(c.get("offPwdFile"), "");
        if (!"".equals(offPwdFiles)) {
            List<File> listFiles = new ArrayList<>();
            for (String offPwdFile : offPwdFiles.split("`")) {
                String localFileName = new StringBuilder(String.valueOf(System.currentTimeMillis())).toString();
                String tempName = offPwdFile.substring(offPwdFile.lastIndexOf("/") + 1);
                if (conf.getKey().equals(ReportService.REPORT_STATE_READY) || (conf.getKey().equals("3") && ObjectUtil.getString(c.get("linuxV"), "").contains("weblogic"))) {
                    localFileName = tempName;
                } else if (tempName.contains(".")) {
                    localFileName = String.valueOf(localFileName) + tempName.substring(tempName.lastIndexOf("."));
                }
                File localFile = new File(Constant.TEMP_DIR, localFileName);
                SftpDownloader.download(ObjectUtil.getString(c.get("uname"), ""), ObjectUtil.getString(c.get("pwd"), ""), ip, 22, localFile.getPath().trim(), offPwdFile.trim());
                if (conf.getKey().equals("3") && ObjectUtil.getString(c.get("linuxV"), "").contains("weblogic")) {
                    listFiles.add(localFile);
                } else if (conf.getKey().equals(ReportService.REPORT_STATE_READY)) {
                    listFiles.add(localFile);
                } else {
                    offlineCheck(localFileName, pwddicFile, pwdList, devid);
                }
            }
            if (listFiles != null && listFiles.size() > 0) {
                File zipFile = new File(Constant.TEMP_DIR, String.valueOf(System.currentTimeMillis()) + ".zip");
                ZipUtil.toZip(zipFile, (File[]) listFiles.toArray(new File[listFiles.size()]), (String) null);
                for (File tf : listFiles) {
                    if (tf != null && tf.exists()) {
                        tf.delete();
                    }
                }
                offlineCheck(zipFile.getName(), pwddicFile, pwdList, devid);
            }
        }
    }

    private void offlineCheck(String uniqname, File pwddicFile, List<Map<String, Object>> pwdList, Integer devid) throws Exception {
        if (StringUtils.isBlank(uniqname)) {
            return;
        }
        File f = new File(Constant.TEMP_DIR, uniqname);
        String filiename = uniqname.toLowerCase();
        File tempHashFile = new File(Constant.TEMP_DIR, String.valueOf(System.currentTimeMillis()) + ".txt");
        if (filiename.endsWith(".txt")) {
            pwdList = execHash(pwddicFile.getAbsolutePath(), f.getAbsolutePath(), "windows离线检查", devid, null);
            this.engineMapper.delPwds1(devid, "windows离线检查");
        } else if (filiename.endsWith(".zip")) {
            File dir = ZipUtil.unZip(f, (File) null, (String) null);
            File passwd = new File(dir, "passwd");
            File shadow = new File(dir, "shadow");
            if (passwd != null && passwd.exists() && shadow != null && shadow.exists()) {
                String pwdextPath = new File(Constant.WORK_DIR, "tools/pwdext").getAbsolutePath();
                Process proc = Runtime.getRuntime().exec(String.valueOf(pwdextPath) + "/unshadow " + passwd.getAbsolutePath() + " " + shadow.getAbsolutePath());
                String result = IOUtils.toString(proc.getInputStream());
                FileUtils.writeStringToFile(tempHashFile, result);
                proc.destroy();
                pwdList = execHash(pwddicFile.getAbsolutePath(), tempHashFile.getAbsolutePath(), "linux离线检查", devid, null);
                this.engineMapper.delPwds1(devid, "linux离线检查");
            } else {
                File pro = new File(dir, "boot.properties");
                File dat = new File(dir, "SerializedSystemIni.dat");
                pwdList = new ArrayList();
                String pwddicContent = "\n" + FileUtils.readFileToString(pwddicFile, "utf8").replaceAll("\r|\n", "\n").replaceAll("[\n]{2,}", "\n") + "\n";
                Map<String, Object> row = WebLogicPwdDecryptor.exec(pro, dat);
                for (Map.Entry<String, Object> e : row.entrySet()) {
                    String p = ObjectUtil.getString(e.getValue(), "");
                    if (StringUtils.isBlank(p)) {
                        row.put("protocol", "weblogic离线检查");
                        pwdList.add(row);
                    }
                }
                if (pwddicContent.contains("\n" + ObjectUtil.getString(row.get("password"), "") + "\n")) {
                    row.put("protocol", "weblogic离线检查");
                    pwdList.add(row);
                }
                this.engineMapper.delPwds1(devid, "weblogic离线检查");
            }
            FileUtils.deleteDirectory(dir);
        } else if (filiename.endsWith(".xml")) {
            String pwddicContent2 = "\n" + FileUtils.readFileToString(pwddicFile, "utf8").replaceAll("\r|\n", "\n").replaceAll("[\n]{2,}", "\n") + "\n";
            Element rootEl = DocumentHelper.parseText(FileUtils.readFileToString(f, "utf8")).getRootElement();
            pwdList = new ArrayList();
            List<Object> users = rootEl.elements("user");
            if (CollectionUtils.isEmpty(users)) {
                Map<String, Object> row2 = new HashMap<>();
                row2.put("protocol", "tomcat离线检查");
                row2.put("username", "");
                row2.put("password", "");
                row2.put("deviceid", devid);
                pwdList.add(row2);
            } else {
                for (Object userObj : users) {
                    Element userEle = (Element) userObj;
                    Object username = userEle.attributeValue("username");
                    String password = userEle.attributeValue("password");
                    if (pwddicContent2.contains("\n" + password + "\n")) {
                        Map<String, Object> row3 = new HashMap<>();
                        row3.put("protocol", "tomcat离线检查");
                        row3.put("username", username);
                        row3.put("password", password);
                        row3.put("deviceid", devid);
                        pwdList.add(row3);
                    }
                }
            }
            if (pwdList.size() == 0) {
                try {
                    List<Element> datasourcesEle = rootEl.selectNodes("//*[name()='datasources']/*[name()='datasource']");
                    for (Element resource : datasourcesEle) {
                        Map<String, Object> resMap = XmlUtils.xml2MapData(resource);
                        Map<String, Object> sec = (Map) resMap.get("security");
                        if (sec != null) {
                            Object username2 = ObjectUtil.getString(sec.get("user-name"), "");
                            String password2 = ObjectUtil.getString(sec.get("password"), "");
                            if (pwddicContent2.contains("\n" + password2 + "\n")) {
                                Map<String, Object> row4 = new HashMap<>();
                                row4.put("protocol", "jboss离线检查（未加密）");
                                row4.put("username", username2);
                                row4.put("password", password2);
                                row4.put("deviceid", devid);
                                pwdList.add(row4);
                            }
                        } else {
                            String secDomainRef = ObjectUtil.getString(resMap.get("security-domain"), "");
                            if (StringUtils.isNotBlank(secDomainRef)) {
                                List<Element> moduleOptions = rootEl.selectNodes("//*[name()='security-domain'][@name='" + secDomainRef + "']/*[name()='authorization']/*[name()='login-module']/*");
                                List<Map<String, Object>> listmap = new ArrayList<>();
                                for (Element mo : moduleOptions) {
                                    listmap.add(XmlUtils.xml2mapWithAttrData(mo));
                                }
                                Map<String, Map<String, Object>> moMap = EntryResult.parseEntryMap(listmap, "@name");
                                Object username3 = ObjectUtil.getString(moMap.get("username").get("@value"), "");
                                String decodePwd = JbossDecryptor.decode(ObjectUtil.getString(moMap.get("password").get("@value"), ""));
                                if (pwddicContent2.contains("\n" + decodePwd + "\n")) {
                                    Map<String, Object> row5 = new HashMap<>();
                                    row5.put("protocol", "jboss离线检查（已加密）");
                                    row5.put("username", username3);
                                    row5.put("password", decodePwd);
                                    row5.put("deviceid", devid);
                                    pwdList.add(row5);
                                }
                            }
                        }
                    }
                } catch (Exception e2) {
                    this.LOG.error("", e2);
                }
            }
            this.engineMapper.delPwds1(devid, "tomcat离线检查");
        } else if (filiename.endsWith(".myd")) {
            Process proc2 = Runtime.getRuntime().exec(new String[]{"/bin/sh", "-c", "strings " + f.getAbsolutePath() + ">" + tempHashFile.getAbsolutePath()});
            proc2.getInputStream();
            proc2.waitFor();
            proc2.destroy();
            pwdList = execHash(pwddicFile.getAbsolutePath(), tempHashFile.getAbsolutePath(), "mysql离线检查", devid, null);
            this.engineMapper.delPwds1(devid, "mysql离线检查");
        } else if (filiename.endsWith(".ora") || filiename.endsWith(".") || !filiename.contains(".")) {
            Process proc3 = Runtime.getRuntime().exec(new String[]{"/bin/sh", "-c", "strings " + f.getAbsolutePath() + ">" + tempHashFile.getAbsolutePath()});
            proc3.getInputStream();
            proc3.waitFor();
            proc3.destroy();
            List<String> oraclePwdList = FileUtils.readLines(tempHashFile, "UTF-8");
            StringBuilder oracleSb = new StringBuilder();
            for (String oraStr : oraclePwdList) {
                if (StringUtils.isNotBlank(oraStr) && oraStr.length() == 16) {
                    for (String oraUser : ORACLE_USER.split("\\|")) {
                        oracleSb.append(oraUser).append(":").append(oraStr).append("\n");
                    }
                }
            }
            FileUtils.writeStringToFile(tempHashFile, oracleSb.toString(), "UTF-8");
            pwdList = execHash(pwddicFile.getAbsolutePath(), tempHashFile.getAbsolutePath(), "Oracle离线检查", devid, "--format=oracle");
            this.engineMapper.delPwds1(devid, "Oracle离线检查");
        }
        if (pwdList != null && pwdList.size() > 0) {
            this.engineMapper.sysAddPwds1(devid, pwdList);
        }
        tempHashFile.delete();
        f.delete();
    }

    public void delete(HttpSession session, Integer id, Integer version) throws Exception {
        int n = this.pwdMapper.queryTaskDevCount((String) null, (Integer) null, 1, id).intValue();
        if (n > 0) {
            throw new UEException("该任务中有" + n + "个资产正在扫描，请先停止该任务中所有正在扫描的资产再删除！");
        }
        delTask(session, id, version);
    }

    public Integer insert(HttpSession session, String name, String desct, Integer type, String alarmMethod, Integer alarmType, String alarmTime, String mailAddr, String smsAddr, String devList, String periodTime, String emailcheck, String smscheck, String confContent, Integer val1, String ftpReportType) throws Exception {
        Map<String, String> params = InitSystemTask.licenseApp.getLicenseLic().getParams();
        String cmp = ObjectUtil.getString(params.get("cmp"), "");
        if (!cmp.contains("pwd")) {
            throw new UEException("弱口令扫描任务未授权");
        }
        LicCmp licCmp = getLicCp(cmp, "pwd");
        if (InitSystemTask.licenseApp.valudate(licCmp.getAuthDay()) != 0) {
            throw new UEException("弱口令任务授权已过期");
        }
        User user = null;
        try {
            user = (User) session.getAttribute("userInfo");
            Integer count = this.pwdMapper.getTaskCountByName(name, 3, user.getId(), (Integer) null);
            if (count != null && count.intValue() > 0) {
                throw new UEException("任务名称已存在！");
            }
        } catch (Exception e) {
            Integer count2 = this.pwdMapper.getTcountForOthers(name, 3, (Integer) null);
            if (count2 != null && count2.intValue() > 0) {
                throw new UEException("任务名称已存在！");
            }
        }
        Integer taskid = add(null, name, desct, type, alarmMethod, alarmType, alarmTime, mailAddr, smsAddr, devList, periodTime, emailcheck, smscheck, null, 3, confContent, val1, ftpReportType, session);
        if (type.intValue() == 1) {
            boolean bl = true;
            List<Map<String, Object>> taskWebList = this.pwdMapper.getTaskDevByTid(taskid);
            for (Map<String, Object> map : taskWebList) {
                Integer devid = ObjectUtil.getInt(map.get("id"));
                try {
                    start(devid);
                } catch (Exception e2) {
                    bl = false;
                    this.LOG.error("立即扫描异常URL（" + map.get("url") + "）：", e2);
                }
            }
            if (bl) {
                this.logMapper.insert(user == null ? "未登录" : user.getName(), "开始扫描弱口令任务", "", 1, "扫描成功");
            } else {
                this.logMapper.insert(user == null ? "未登录" : user.getName(), "开始扫描弱口令任务", "", 2, "扫描失败");
            }
        }
        startTimer(taskid, type, periodTime, alarmType, alarmMethod, alarmTime);
        return taskid;
    }

    @Transactional
    public void insertOffPwd(HttpSession session, String name, String desct, String devList, String confContent, Integer val1, String ftpReportType) throws Exception {
        File pwddicFile;
        Map<String, String> params = InitSystemTask.licenseApp.getLicenseLic().getParams();
        String cmp = ObjectUtil.getString(params.get("cmp"), "");
        if (!cmp.contains("pwd")) {
            throw new UEException("弱口令扫描任务未授权");
        }
        LicCmp licCmp = getLicCp(cmp, "pwd");
        if (InitSystemTask.licenseApp.valudate(licCmp.getAuthDay()) != 0) {
            throw new UEException("弱口令任务授权已过期");
        }
        Integer uid = ((User) session.getAttribute("userInfo")).getId();
        Integer count = this.pwdMapper.getTaskCountByName(name, 3, uid, (Integer) null);
        if (count != null && count.intValue() > 0) {
            throw new UEException("任务名称已存在！");
        }
        Integer taskid = add(null, name, desct, 1, null, 0, null, null, null, devList, null, null, null, null, 10, confContent, val1, ftpReportType, session);
        List<Map<String, Object>> devs = (List) JsonUtil.MAPPER.readValue(devList, List.class);
        if (CollectionUtils.isNotEmpty(devs)) {
            Map<String, Object> confMap = (Map) JsonUtil.MAPPER.readValue(ObjectUtil.getString(confContent, "{}"), new TypeReference<Map<String, Object>>() { // from class: com.datacloudsec.scan.service.impl.PwdService.2
            });
            Map<String, Object> pwddic = this.pwddicMapper.getTemplateById(ObjectUtil.getInt(confMap.get("passwords")));
            String pwddicPath = ObjectUtil.getString(pwddic.get("path"), (String) null);
            if (pwddicPath == null) {
                pwddicFile = new File(Constant.TEMP_DIR, String.valueOf(System.nanoTime()) + ".txt");
                FileUtils.writeStringToFile(pwddicFile, ObjectUtil.getString(pwddic.get("content"), "").replace("|", "\n"));
            } else {
                pwddicFile = new File(Constant.PWDDIC_DIC, pwddicPath);
            }
            for (Map<String, Object> dev : devs) {
                Integer id = this.pwdMapper.getDevIdByTidAndIp(taskid, ObjectUtil.getString(dev.get("name"), ""));
                if (id != null) {
                    impOfflinePwd(dev.get("uniqname"), id);
                }
                String pwd = ObjectUtil.getString(dev.get("pwd"), "");
                if (StringUtils.isNotBlank(pwd)) {
                    List<Map<String, Object>> pwdList = new ArrayList<>();
                    int encrypt = ObjectUtil.getInt(dev.get("encrypt"), 0);
                    if (encrypt == 1) {
                        String encType = ObjectUtil.getString(dev.get("encType"), "");
                        if ("oracle".equalsIgnoreCase(encType)) {
                            for (String hash : pwd.split("\n")) {
                                StringBuilder oracleSb = new StringBuilder();
                                for (String oraUser : ORACLE_USER.split("\\|")) {
                                    oracleSb.append(oraUser).append(":").append(hash).append("\n");
                                }
                                String hash2 = oracleSb.toString();
                                File ufile = new File(Constant.TEMP_DIR, new StringBuilder(String.valueOf(System.nanoTime())).toString());
                                FileUtils.writeStringToFile(ufile, hash2, "UTF-8");
                                pwdList.addAll(execHash(pwddicFile.getAbsolutePath(), ufile.getAbsolutePath(), "手工录入-" + encType, id, "--format=oracle"));
                            }
                        } else if ("tomcat".equalsIgnoreCase(encType)) {
                            String pwds = FileUtils.readFileToString(pwddicFile, "UTF-8").replaceAll("\r|\n", "\n").replaceAll("[\n]{2,}", "\n");
                            if (StringUtils.isNotBlank(pwds)) {
                                Sets.SetView<String> pwdSets = Sets.intersection(Sets.newHashSet(Arrays.asList(pwd.split("\n"))), Sets.newHashSet(Arrays.asList(pwds.split("\n"))));
                                Iterator it = pwdSets.iterator();
                                while (it.hasNext()) {
                                    String p = (String) it.next();
                                    Map<String, Object> pmap = new HashMap<>();
                                    pmap.put("password", p);
                                    pmap.put("protocol", "手工录入-" + encType);
                                    pwdList.add(pmap);
                                }
                            }
                        } else if ("windows".equalsIgnoreCase(encType) || "mysql".equalsIgnoreCase(encType) || "sqlserver".equalsIgnoreCase(encType)) {
                            File ufile2 = new File(Constant.TEMP_DIR, new StringBuilder(String.valueOf(System.nanoTime())).toString());
                            FileUtils.writeStringToFile(ufile2, pwd, "UTF-8");
                            pwdList.addAll(execHash(pwddicFile.getAbsolutePath(), ufile2.getAbsolutePath(), "手工录入-" + encType, id, null));
                        } else if ("jboss".equalsIgnoreCase(encType)) {
                            String pwds2 = "\n" + FileUtils.readFileToString(pwddicFile, "UTF-8").replaceAll("\r|\n", "\n").replaceAll("[\n]{2,}", "\n") + "\n";
                            for (String hash3 : pwd.split("\n")) {
                                String password = JbossDecryptor.decode(hash3);
                                if (pwds2.contains(password)) {
                                    Map<String, Object> pmap2 = new HashMap<>();
                                    pmap2.put("password", password);
                                    pmap2.put("protocol", "手工录入-" + encType);
                                    pwdList.add(pmap2);
                                }
                            }
                        }
                    } else {
                        String pwds3 = FileUtils.readFileToString(pwddicFile, "UTF-8").replaceAll("\r|\n", "\n").replaceAll("[\n]{2,}", "\n");
                        if (StringUtils.isNotBlank(pwds3)) {
                            Sets.SetView<String> pwdSets2 = Sets.intersection(Sets.newHashSet(Arrays.asList(pwd.split("\n"))), Sets.newHashSet(Arrays.asList(pwds3.split("\n"))));
                            Iterator it2 = pwdSets2.iterator();
                            while (it2.hasNext()) {
                                String p2 = (String) it2.next();
                                Map<String, Object> pmap3 = new HashMap<>();
                                pmap3.put("password", p2);
                                pmap3.put("protocol", "手工录入");
                                pwdList.add(pmap3);
                            }
                        }
                    }
                    if (pwdList != null && pwdList.size() > 0) {
                        this.engineMapper.sysAddPwds1(id, pwdList);
                    }
                }
            }
        }
    }

    private Integer add(Integer id, String name, String desct, Integer type, String alarmMethod, Integer alarmType, String alarmTime, String mailAddr, String smsAddr, String devList, String periodTime, String emailcheck, String smscheck, Integer version, Integer taskType, String confContent, Integer val1, String ftpReportType, HttpSession session) throws Exception {
        String ip;
        Map<String, String> params = InitSystemTask.licenseApp.getLicenseLic().getParams();
        String cmp = ObjectUtil.getString(params.get("cmp"), "");
        LicCmp licCmp = getLicCp(cmp, "pwd");
        int maxdevice = licCmp.getMaxdevice();
        User user = (User) session.getAttribute("userInfo");
        String rule = DataRule.getRuleWhere(session, "t_task");
        Task task = new Task();
        task.setName(name);
        if (id != null) {
            task.setId(id);
        }
        task.setDesct(desct);
        task.setType(type);
        task.setAlarmMethod(alarmMethod);
        task.setAlarmType(alarmType);
        task.setAlarmTime(alarmTime);
        task.setMailAddr(emailcheck);
        task.setSmsAddr(smscheck);
        task.setPeriodTime(periodTime);
        task.setUid(Integer.valueOf(user == null ? 1 : user.getId().intValue()));
        task.setTaskType(taskType);
        task.setVersion(version);
        task.setRule(rule);
        task.setConfContent(confContent);
        task.setVal1(val1);
        task.setVal2(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));
        task.setFtpReportType(ftpReportType);
        if (id != null) {
            task.setId(id);
        }
        if (id == null) {
            List<Map<String, Object>> devListMap = (List) JsonUtil.MAPPER_ESCAPE_HTML.readValue(devList, ArrayList.class);
            int devIpCount = 0;
            for (Map<String, Object> devMap : devListMap) {
                Map<String, Object> map = this.deviceMapper.getDevById(ObjectUtil.getInt(devMap.get("id")));
                if (map != null) {
                    ip = ObjectUtil.getString(map.get("ip"), "");
                } else {
                    ip = ObjectUtil.getString(devMap.get("name"), "");
                }
                if (user != null && StringUtils.isNotBlank(user.getIps()) && !IPUtil.ipVaild(ip, user.getIps())) {
                    throw new UEException("IP【" + ip + "】不在扫描范围内，可联系管理员授权扫描此IP");
                }
                devIpCount++;
            }
            if (maxdevice > 0 && this.pwdMapper.getCountByType((String) null) + devIpCount > maxdevice) {
                throw new UEException("当前资产数已达授权上限[" + maxdevice + "]");
            }
            this.pwdMapper.insert(task);
            for (Map<String, Object> devMap2 : devListMap) {
                Map<String, Object> map2 = this.deviceMapper.getDevById(ObjectUtil.getInt(devMap2.get("id")));
                if (map2 != null) {
                    Map<String, Object> devGroup = this.deviceGroupMapper.getDevGroupById(ObjectUtil.getInt(map2.get("dgid")));
                    map2.put("devgroup", ObjectUtil.getString(devGroup.get("name"), ""));
                    map2.put("taskId", task.getId());
                    map2.put("type", null);
                    if (taskType.intValue() == 10) {
                        map2.put("status", 2);
                    }
                    map2.put("confContent", ObjectUtil.getString(map2.get("authContent"), ""));
                    map2.put("val3", ObjectUtil.getString(map2.get("val2"), ""));
                    map2.put("val2", ObjectUtil.getString(map2.get("val1"), ""));
                    map2.put("val1", ObjectUtil.getString(devMap2.get("pwd"), ""));
                    this.pwdMapper.insertTaskDevice(map2);
                } else {
                    Map<String, Object> newdev = new HashMap<>();
                    newdev.put("type", null);
                    newdev.put("taskId", task.getId());
                    newdev.put("name", ObjectUtil.getString(devMap2.get("name"), ""));
                    newdev.put("ip", ObjectUtil.getString(devMap2.get("name"), ""));
                    newdev.put("regionSid", Integer.valueOf((user == null || user.getRegionSid() == null) ? 110000 : user.getRegionSid().intValue()));
                    newdev.put("regionCid", Integer.valueOf((user == null || user.getRegionCid() == null) ? 110101 : user.getRegionCid().intValue()));
                    newdev.put("val1", ObjectUtil.getString(devMap2.get("pwd"), ""));
                    this.pwdMapper.insertTaskDevice(newdev);
                }
            }
        } else {
            Integer rcount = this.pwdMapper.update(task);
            if (rcount != null && rcount.intValue() == 0) {
                throw new UEException("数据已被修改或删除，请刷新页面或返回");
            }
        }
        if (user != null) {
            if (StringUtils.isNotBlank(mailAddr)) {
                this.pwdMapper.delEmail(user.getId());
                String[] mail = mailAddr.split(",");
                for (String ml : mail) {
                    this.pwdMapper.insertEmail(ml, user.getId());
                }
            }
            if (StringUtils.isNotBlank(smsAddr)) {
                this.pwdMapper.delPhone(user.getId());
                String[] sms = smsAddr.split(",");
                for (String s : sms) {
                    this.pwdMapper.insertPhone(s, user.getId());
                }
            }
        }
        return task.getId();
    }

    public void insertTaskDev(Map<String, Object> map) throws Exception {
        this.pwdMapper.insertTaskDevice(map);
    }

    public void update(HttpSession session, Integer id, String name, String desct, Integer type, String alarmMethod, Integer alarmType, String alarmTime, String mailAddr, String smsAddr, String periodTime, String emailcheck, String smscheck, Integer version, String confContent, Integer val1, String ftpReportType) throws Exception {
        Integer uid = ((User) session.getAttribute("userInfo")).getId();
        Integer count = this.pwdMapper.getTaskCountByName(name, 3, uid, id);
        if (count != null && count.intValue() > 0) {
            throw new UEException("任务名称已存在！");
        }
        add(id, name, desct, type, alarmMethod, alarmType, alarmTime, mailAddr, smsAddr, null, periodTime, emailcheck, smscheck, version, 3, confContent, val1, ftpReportType, session);
        stopTimer(session, id);
        if (alarmType.intValue() == 2 || type.intValue() == 2) {
            startTimer(id, type, periodTime, alarmType, alarmMethod, alarmTime);
        }
    }

    public void updateOffPwd(HttpSession session, Integer id, String name, String desct, String confContent, Integer version, Integer val1, String uniqname, String ftpReportType) throws Exception {
        Integer uid = ((User) session.getAttribute("userInfo")).getId();
        Integer count = this.pwdMapper.getTaskCountByName(name, 10, uid, id);
        if (count != null && count.intValue() > 0) {
            throw new UEException("任务名称已存在！");
        }
        add(id, name, desct, 0, null, 0, null, null, null, null, null, null, null, version, 10, confContent, val1, ftpReportType, session);
        List<Map<String, Object>> devLists = this.pwdMapper.getTaskDevByTid(id);
        if (devLists != null && devLists.size() > 0) {
            Map<String, Object> dev0 = devLists.get(0);
            Integer devid0 = ObjectUtil.getInt(dev0.get("id"));
            impOfflinePwd(uniqname, devid0);
            List<Map<String, Object>> buglist = this.pwdMapper.getBugByDevId(devid0);
            if (buglist == null || buglist.size() == 0) {
                return;
            }
            for (int i = 1; i < devLists.size(); i++) {
                Map<String, Object> dev = devLists.get(i);
                Integer devid = ObjectUtil.getInt(dev.get("id"));
                this.engineMapper.sysAddPwds1(devid, buglist);
                Integer pwdCount = this.sysBugMapper.pwdCountByDev(devid);
                this.sysBugMapper.insertPwdStatics(pwdCount, new Date(), devid);
                Integer pwdStaCount = this.sysBugMapper.pwdStaCount();
                if (pwdStaCount != null && pwdStaCount.intValue() > 7) {
                    this.sysBugMapper.delPwdStaOneWeek();
                }
            }
        }
    }

    public void start(Integer devid) throws Exception {
        Map<String, Object> pwd = this.pwdMapper.getTaskDevById(devid);
        if (pwd == null) {
            throw new UEException("此任务已被其它用户删除！");
        }
        int status = ObjectUtil.getInt(pwd.get("status"), 1);
        if (status != 1) {
            SqlSession session = null;
            try {
                try {
                    session = MybatisUtil.sqlSessionFactory.openSession(true);
                    SysBugMapper sysBugMapper = (SysBugMapper) session.getMapper(SysBugMapper.class);
                    TaskMapper taskMapper = (TaskMapper) session.getMapper(TaskMapper.class);
                    sysBugMapper.delSysPwd2(devid);
                    Map<String, Object> dmap = new HashMap<>();
                    dmap.put("offset1", 0);
                    dmap.put("offset2", 0);
                    dmap.put("offset3", 0);
                    dmap.put("progress", 0);
                    dmap.put("devid", devid);
                    taskMapper.updateTaskDevice(dmap);
                    session.commit();
                    if (session != null) {
                        session.close();
                    }
                    Task task = this.pwdMapper.getTaskById(ObjectUtil.getInt(pwd.get("taskId")));
                    Map<String, String> taskOption = (Map) JsonUtil.MAPPER.readValue(task.getConfContent(), new TypeReference<Map<String, String>>() { // from class: com.datacloudsec.scan.service.impl.PwdService.3
                    });
                    Map<String, String> taskParam = new HashMap<>();
                    List<Map<String, String>> taskProtocolParam = new ArrayList<>();
                    for (Map.Entry<String, String> entry : taskOption.entrySet()) {
                        if (entry.getKey().contains("protocol")) {
                            Map<String, String> protocolParam = new HashMap<>();
                            protocolParam.put("protocol", entry.getValue());
                            String[] keys = entry.getKey().split("_");
                            if (taskOption.containsKey(String.valueOf(keys[1]) + "_ssl")) {
                                protocolParam.put("ssl", taskOption.get(String.valueOf(keys[1]) + "_ssl"));
                            }
                            protocolParam.put("port", taskOption.get(String.valueOf(keys[1]) + "_port"));
                            if (keys[1].equalsIgnoreCase("oracle")) {
                                protocolParam.put("other", taskOption.get("other"));
                            }
                            taskProtocolParam.add(protocolParam);
                        } else if (!entry.getKey().contains("protocol") && !entry.getKey().contains("ssl") && !entry.getKey().contains("port") && !entry.getKey().contains("other")) {
                            if (entry.getKey().equals("usernames") || entry.getKey().equals("passwords")) {
                                Map<String, Object> pwddic = this.pwddicMapper.getTemplateById(ObjectUtil.getInt(entry.getValue()));
                                if (MapUtils.isNotEmpty(pwddic)) {
                                    String path = ObjectUtil.getString(pwddic.get("path"), "");
                                    if (StringUtils.isNotBlank(path)) {
                                        File f = new File(Constant.PWDDIC_DIC, ObjectUtil.getString(pwddic.get("path"), ""));
                                        taskParam.put(entry.getKey(), FileUtils.readFileToString(f, "UTF-8"));
                                    } else {
                                        taskParam.put(entry.getKey(), ObjectUtil.getString(pwddic.get("content"), ""));
                                    }
                                }
                            } else {
                                taskParam.put(entry.getKey(), entry.getValue());
                            }
                        }
                    }
                    if (!"".equals(ObjectUtil.getString(taskParam.get("protType"), ""))) {
                        Iterator<Map<String, String>> it = taskProtocolParam.iterator();
                        while (true) {
                            if (!it.hasNext()) {
                                break;
                            }
                            Map<String, String> param = it.next();
                            if ("http".equalsIgnoreCase(ObjectUtil.getString(param.get("protocol"), ""))) {
                                StringBuilder sb = new StringBuilder();
                                sb.append(ObjectUtil.getString(taskParam.get("reqPath"), ""));
                                sb.append(":").append(ObjectUtil.getString(taskParam.get("reqParams"), ""));
                                sb.append(":").append(ObjectUtil.getString(taskParam.get("reFlag"), "")).append("=").append(ObjectUtil.getString(taskParam.get("reVal"), ""));
                                param.put("other", sb.toString());
                                param.put("protocol", String.valueOf(ObjectUtil.getString(taskParam.get("protType"), "")) + "-" + ObjectUtil.getString(taskParam.get("method"), "") + "-form");
                                break;
                            }
                        }
                    }
                    try {
                        IEngine.EngineResult eresult = this.engine.pwdScan(ObjectUtil.getString(pwd.get("ip"), ""), taskParam, taskProtocolParam);
                        if (eresult != null) {
                            Map<String, Object> taskwebmap = new HashMap<>();
                            taskwebmap.put("devid", devid);
                            taskwebmap.put("engineId", eresult.getEngineId());
                            taskwebmap.put("localEid", Integer.valueOf(eresult.getLocalId()));
                            taskwebmap.put("status", 1);
                            taskwebmap.put("startTime", new Date());
                            taskwebmap.put("scanCount", Integer.valueOf(ObjectUtil.getInt(pwd.get("scanCount"), 0) + 1));
                            this.pwdMapper.updateTaskDevice(taskwebmap);
                            return;
                        }
                        Map<String, Object> taskwebmap2 = new HashMap<>();
                        taskwebmap2.put("devid", devid);
                        taskwebmap2.put("status", 4);
                        this.pwdMapper.updateTaskDevice(taskwebmap2);
                    } catch (Exception e) {
                        Object error = e instanceof UEException ? e.getMessage() : "连接引擎出错";
                        Map<String, Object> emap = new HashMap<>();
                        emap.put("error", error);
                        emap.put("status", 3);
                        emap.put("devid", devid);
                        this.pwdMapper.updateTaskDevice(emap);
                        this.LOG.error("", e);
                    }
                } catch (Throwable th) {
                    if (session != null) {
                        session.close();
                    }
                    throw th;
                }
            } catch (Exception e2) {
                session.rollback();
                throw e2;
            }
        }
    }

    public void stop(Integer devid) throws Exception {
        Map<String, Object> dev = this.pwdMapper.getTaskDevById(devid);
        if (dev == null) {
            throw new UEException("此任务已被其它用户删除！");
        }
        String eid = ObjectUtil.getString(dev.get("engineId"), (String) null);
        int status = ObjectUtil.getInt(dev.get("status"), 0);
        if (status == 1) {
            this.engine.pwdStop(eid, ObjectUtil.getInt(dev.get("localEid")).intValue());
            Map<String, Object> map = new HashMap<>();
            map.put("devid", devid);
            map.put("engineId", eid);
            map.put("status", 0);
            this.pwdMapper.updateTaskDevice(map);
            Integer scanCount = Integer.valueOf(ObjectUtil.getInt(dev.get("scanCount"), 0));
            if (scanCount.intValue() != 1) {
                this.sysBugMapper.delSysPwd(devid);
                this.sysBugMapper.delSysPwd2(devid);
            }
            Integer pwdCount = this.sysBugMapper.pwdCountByDev(devid);
            this.sysBugMapper.insertPwdStatics(pwdCount, new Date(), devid);
            Integer pwdStaCount = this.sysBugMapper.pwdStaCount();
            if (pwdStaCount != null && pwdStaCount.intValue() > 7) {
                this.sysBugMapper.delPwdStaOneWeek();
            }
        }
        Map<String, Object> waitingDev = this.engineMapper.getWaitingDev(3, devid);
        if (waitingDev != null && waitingDev.size() > 0) {
            start(ObjectUtil.getInt(waitingDev.get("id")));
        }
    }

    public void startScanTask(Integer taskId) throws Exception {
        List<Map<String, Object>> taskDevList = this.pwdMapper.getTaskDevByTid(taskId);
        if (taskDevList == null) {
            throw new UEException("此任务已被其它用户删除！");
        }
        for (Map<String, Object> dev : taskDevList) {
            if (1 != ObjectUtil.getInt(dev.get("status")).intValue()) {
                Integer devid = ObjectUtil.getInt(dev.get("id"));
                try {
                    start(devid);
                } catch (Exception e) {
                    this.LOG.error("手动扫描出错", e);
                }
            }
        }
    }

    public void stopScanTask(Integer taskId) throws Exception {
        List<Map<String, Object>> taskDevList = this.pwdMapper.getTaskDevByTid(taskId);
        if (taskDevList == null) {
            throw new UEException("此任务已被其它用户删除！");
        }
        for (Map<String, Object> dev : taskDevList) {
            Integer devid = ObjectUtil.getInt(dev.get("id"));
            try {
                stop(devid);
            } catch (Exception e) {
                this.LOG.error("停止出错", e);
            }
        }
        Task t = this.pwdMapper.getTaskById(taskId);
        if (ObjectUtil.getInt(t.getAlarmType(), 0) == 1) {
            AlermJob.alermTask(taskId);
        }
    }

    public void delDev(Integer devId) throws Exception {
        Map<String, Object> webMap = this.pwdMapper.getTaskDevById(devId);
        if (1 == ObjectUtil.getInt(webMap.get("status")).intValue()) {
            throw new UEException("正在扫描，请先停止后再删除！");
        }
        String eid = ObjectUtil.getString(webMap.get("engineId"), "");
        if (StringUtils.isNotBlank(eid)) {
            this.engine.pwdDelete(eid, ObjectUtil.getInt(webMap.get("localEid")).intValue());
        }
        SqlSession session = null;
        try {
            try {
                session = MybatisUtil.sqlSessionFactory.openSession(true);
                SysBugMapper sysBugMapper = (SysBugMapper) session.getMapper(SysBugMapper.class);
                PwdMapper pwdMapper = (PwdMapper) session.getMapper(PwdMapper.class);
                sysBugMapper.delSysPwd(devId);
                sysBugMapper.clearPwdStatistics(devId);
                pwdMapper.delTaskDevById(devId);
                session.commit();
                if (session != null) {
                    session.close();
                }
            } catch (Exception e) {
                if (session != null) {
                    session.rollback();
                }
                throw e;
            }
        } catch (Throwable th) {
            if (session != null) {
                session.close();
            }
            throw th;
        }
    }

    public void addDev(HttpSession session, String devIds, Integer taskId, Boolean isOffPwd) throws Exception {
        Map<String, String> params = InitSystemTask.licenseApp.getLicenseLic().getParams();
        String cmp = ObjectUtil.getString(params.get("cmp"), "");
        LicCmp licCmp = getLicCp(cmp, "pwd");
        int maxdevice = licCmp.getMaxdevice();
        String[] devIdArr = devIds.split(",");
        int devIpCount = devIdArr.length;
        if (maxdevice > 0 && this.pwdMapper.getCountByType((String) null) + devIpCount > maxdevice) {
            throw new UEException("当前资产数已达授权上限[" + maxdevice + "]");
        }
        List<Integer> devices = new ArrayList<>();
        for (String str : devIdArr) {
            Map<String, Object> devMap = this.deviceMapper.getDevById(ObjectUtil.getInt(str));
            devMap.put("taskId", taskId);
            devMap.put("type", null);
            devMap.put("confContent", ObjectUtil.getString(devMap.get("authContent"), ""));
            this.pwdMapper.insertTaskDevice(devMap);
            devices.add(ObjectUtil.getInt(devMap.get("id")));
        }
        for (Integer devid : devices) {
            Task task = this.pwdMapper.getTaskById(taskId);
            if (task != null && task.getType().intValue() == 1) {
                User user = (User) session.getAttribute("userInfo");
                boolean bl = true;
                if (isOffPwd.booleanValue()) {
                    impOfflinePwd(null, devid);
                } else {
                    try {
                        start(devid);
                    } catch (Exception e) {
                        bl = false;
                        this.LOG.error("", e);
                    }
                }
                if (bl) {
                    this.logMapper.insert(user == null ? "未登录" : user.getName(), "开始扫描弱口令任务", "", 1, "扫描成功");
                } else {
                    this.logMapper.insert(user == null ? "未登录" : user.getName(), "开始扫描弱口令任务", "", 2, "扫描失败");
                }
            }
        }
    }

    public List<Map<String, Object>> getDevDetailByTid(Integer id) throws Exception {
        return this.pwdMapper.getDevDetailByTid(id);
    }

    public List<Map<String, Object>> bugPie(Integer id) throws Exception {
        return this.pwdMapper.bugPie(id);
    }

    public List<Map<String, Object>> pwdResult(Integer id, Integer offset, Integer limit) throws Exception {
        return this.pwdMapper.pwdResult(id, offset, limit);
    }

    public Integer pwdResCount(Integer id) throws Exception {
        return this.pwdMapper.pwdResCount(id);
    }

    public List<Map<String, Object>> pwdBugForDevice(Integer id) throws Exception {
        return this.pwdMapper.pwdBugForDevice(id);
    }

    private void delTask(HttpSession session, Integer id, Integer version) throws Exception {
        List<Map<String, Object>> devList = this.pwdMapper.getTaskDevByTid(id);
        Exception ex = null;
        int count = 0;
        for (Map<String, Object> dev : devList) {
            try {
                String engineId = ObjectUtil.getString(dev.get("engineId"), "");
                if (StringUtils.isNotBlank(engineId)) {
                    this.engine.pwdDelete(engineId, ObjectUtil.getInt(dev.get("localEid")).intValue());
                }
                count++;
            } catch (Exception e) {
                this.LOG.error("", e);
                ex = e;
            }
        }
        if (count == 0) {
            throw ex;
        }
        Iterator<Map<String, Object>> it = devList.iterator();
        while (it.hasNext()) {
            Integer did = ObjectUtil.getInt(it.next().get("id"));
            this.sysBugMapper.delSysPwd(did);
            this.sysBugMapper.delSysPwd2(did);
            this.sysBugMapper.clearPwdStatistics(did);
        }
        stopTimer(session, id);
        this.pwdMapper.delTaskDevByTid(id);
        Integer rcount = Integer.valueOf(this.pwdMapper.delete(id, version, DataRule.getRuleWhere(session, "t_task")));
        if (rcount.intValue() == 0) {
            throw new UEException("数据已被修改或删除，请刷新页面或返回");
        }
    }

    public int markBugErr(Integer id, Integer status) throws Exception {
        return this.pwdMapper.markBugErr(id, status);
    }

    public void manualAddPwd(HttpSession session, String ip, Integer taskId) throws Exception {
        Map<String, String> params = InitSystemTask.licenseApp.getLicenseLic().getParams();
        String cmp = ObjectUtil.getString(params.get("cmp"), "");
        LicCmp licCmp = getLicCp(cmp, "pwd");
        int maxdevice = licCmp.getMaxdevice();
        if (maxdevice > 0 && this.pwdMapper.getCountByType((String) null) + 1 > maxdevice) {
            throw new UEException("当前资产数已达授权上限[" + maxdevice + "]");
        }
        Task task = this.pwdMapper.getTaskById(taskId);
        User user = (User) session.getAttribute("userInfo");
        Map<String, Object> web = new HashMap<>();
        web.put("name", ip);
        web.put("ip", ip);
        web.put("type", null);
        web.put("taskId", taskId);
        web.put("regionCid", user.getRegionCid());
        web.put("regionSid", Integer.valueOf(user.getRegionSid() == null ? 110000 : user.getRegionSid().intValue()));
        this.pwdMapper.insertTaskDevice(web);
        if (task != null && task.getType().intValue() == 1) {
            try {
                start(ObjectUtil.getInt(web.get("id")));
            } catch (Exception e) {
                this.LOG.error("", e);
            }
        }
    }

    public File pwdBackup(Task t) throws Exception {
        File dir = new File(Constant.TEMP_DIR, new StringBuilder(String.valueOf(System.nanoTime())).toString());
        if (!dir.exists()) {
            dir.mkdirs();
        }
        File f = new File(Constant.TEMP_DIR, new StringBuilder(String.valueOf(System.nanoTime())).toString());
        try {
            SerializeUtil.serializeObj(new File(dir, "task.backup"), t);
            List<Map<String, Object>> devList = this.pwdMapper.getTaskDevByTid(t.getId());
            for (Map<String, Object> dev : devList) {
                Integer devid = ObjectUtil.getInt(dev.get("id"));
                File devDir = new File(dir, new StringBuilder().append(devid).toString());
                if (!devDir.exists()) {
                    devDir.mkdirs();
                }
                SerializeUtil.serializeObj(new File(devDir, "dev.backup"), dev);
                SerializeUtil.serializeObj(new File(devDir, "bug.backup"), this.pwdMapper.getBugByDevId(devid));
                SerializeUtil.serializeObj(new File(devDir, "bug2.backup"), this.pwdMapper.getBug2ByDevId(devid));
                SerializeUtil.serializeObj(new File(devDir, "sta.backup"), this.pwdMapper.getStaByDevId(devid));
            }
            ComonZipUtil.zip(dir.getPath(), f.getPath());
            if (dir != null && dir.exists()) {
                FileUtils.deleteDirectory(dir);
            }
            return f;
        } catch (Exception e) {
            throw e;
        }
    }

    public void pwdRestore(HttpSession session, File f) throws Exception {
        File unzipFile = new File(Constant.COMMON_DIR, new StringBuilder(String.valueOf(System.nanoTime())).toString());
        ComonZipUtil.unzip(f, unzipFile);
        File taskFile = new File(unzipFile, "task.backup");
        Task t = (Task) SerializeUtil.deserializeObj(taskFile);
        Integer uid = ((User) session.getAttribute("userInfo")).getId();
        Integer count = this.pwdMapper.getTaskCountByName(t.getName(), 3, uid, (Integer) null);
        if (count != null && count.intValue() > 0) {
            throw new UEException("pwdTaskAlready:" + unzipFile.getName());
        }
        try {
            restore(unzipFile, t);
        } catch (Exception e) {
            FileUtils.deleteDirectory(unzipFile);
            throw e;
        }
    }

    private void restore(File unzipFile, Task t) throws Exception {
        Map<String, Object> device;
        if (unzipFile == null || t == null) {
            return;
        }
        this.pwdMapper.insert(t);
        for (File taskDir : unzipFile.listFiles()) {
            if (!taskDir.getName().equals("task.backup") && (device = (Map) SerializeUtil.deserializeObj(new File(taskDir, "dev.backup"))) != null && device.size() != 0) {
                device.put("taskId", t.getId());
                this.pwdMapper.inserTaskDevById(device);
                Integer devId = ObjectUtil.getInt(device.get("id"));
                List<Map<String, Object>> bugs = (List) SerializeUtil.deserializeObj(new File(taskDir, "bug.backup"));
                if (bugs != null && bugs.size() > 0) {
                    this.pwdMapper.insertPwds(devId, bugs);
                }
                List<Map<String, Object>> bugs2 = (List) SerializeUtil.deserializeObj(new File(taskDir, "bug2.backup"));
                if (bugs2 != null && bugs2.size() > 0) {
                    this.pwdMapper.insertPwds2(devId, bugs2);
                }
                List<Map<String, Object>> stas = (List) SerializeUtil.deserializeObj(new File(taskDir, "sta.backup"));
                if (stas != null && stas.size() > 0) {
                    this.pwdMapper.inserPwdSta(devId, stas);
                }
            }
        }
        startTimer(t.getId(), t.getType(), t.getPeriodTime(), t.getAlarmType(), t.getAlarmMethod(), t.getAlarmTime());
        FileUtils.deleteDirectory(unzipFile);
    }

    public void pwdEnter(HttpSession session, String filename) throws Exception {
        File f = new File(Constant.COMMON_DIR, filename);
        if (f == null || !f.exists()) {
            this.LOG.error("弱口令恢复，文件不存在！");
            return;
        }
        User u = (User) session.getAttribute("userInfo");
        Task t = (Task) SerializeUtil.deserializeObj(new File(f, "task.backup"));
        t.setName(String.valueOf(t.getName()) + System.nanoTime());
        t.setUid(u.getId());
        try {
            restore(f, t);
        } catch (Exception e) {
            FileUtils.deleteDirectory(f);
            throw e;
        }
    }

    private List<Map<String, Object>> execHash(String pwddicPath, String hashPath, String protocol, Integer devid, String format) throws IOException, InterruptedException {
        String pwdextPath = new File(Constant.WORK_DIR, "tools/pwdext").getAbsolutePath();
        long session = System.currentTimeMillis();
        this.LOG.error("执行：" + pwdextPath + "/john --session=" + session + " --pot=" + session + ".pot --encoding=utf8 --wordlist=" + pwddicPath + " " + ObjectUtil.getString(format, "") + " " + hashPath);
        Process proc = Runtime.getRuntime().exec(String.valueOf(pwdextPath) + "/john --session=" + session + " --pot=" + session + ".pot --encoding=utf8 --wordlist=" + pwddicPath + " " + ObjectUtil.getString(format, "") + " " + hashPath);
        String result = IOUtils.toString(proc.getInputStream(), "utf8");
        this.LOG.error("结果:" + result);
        proc.destroy();
        String[] lines = result.replaceAll("\r|\n", "\n").replaceAll("[\n]{2,}", "\n").split("\n");
        List<Map<String, Object>> list = new ArrayList<>();
        for (String line : lines) {
            if (line.endsWith(")") && line.contains(" (")) {
                String[] userPass = line.split(" \\(");
                if (!userPass[1].contains(" ")) {
                    Map<String, Object> row = new HashMap<>();
                    row.put("protocol", protocol);
                    row.put("deviceid", devid);
                    row.put("username", userPass[1].replace(")", ""));
                    row.put("password", userPass[0]);
                    list.add(row);
                }
            }
        }
        new File(String.valueOf(session) + ".log").delete();
        new File(String.valueOf(session) + ".pot").delete();
        return list;
    }

    public void impPwd(HttpSession session, File f) throws Exception {
        List<String[]> strlist = PoiExcelUtils.readExcel(f.getPath(), 0, 3);
        List<Map<String, Object>> data = new ArrayList<>();
        int len = strlist.size();
        for (int i = 2; i < len; i++) {
            String[] strArr = strlist.get(i);
            if (strArr != null && strArr.length >= 3 && !StringUtils.isBlank(strArr[0]) && !StringUtils.isBlank(strArr[1]) && !StringUtils.isBlank(strArr[2])) {
                Map<String, Object> map = new HashMap<>();
                map.put("ip", strArr[0]);
                map.put("hash", strArr[1]);
                map.put("type", strArr[2]);
                data.add(map);
            }
        }
        if (CollectionUtils.isEmpty(data)) {
            throw new UEException("请至少录入一条数据！");
        }
        User user = (User) session.getAttribute("userInfo");
        Task task = new Task();
        task.setName(String.valueOf(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date())) + "（excel导入）");
        task.setDesct("离线弱口令excel批量导入");
        task.setType(1);
        task.setAlarmMethod("system");
        task.setAlarmType(1);
        task.setUid(user.getId());
        task.setTaskType(10);
        task.setVersion(0);
        task.setRule(DataRule.getRuleWhere(session, "t_task"));
        task.setVal1(2);
        task.setVal2(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));
        this.pwdMapper.insert(task);
        File pwddicFile = new File(Constant.PWDDIC_DIC, "system/password.txt");
        String pwds = FileUtils.readFileToString(pwddicFile, "UTF-8").replaceAll("\r|\n", "\n").replaceAll("[\n]{2,}", "\n");
        Map<String, List<Map<String, Object>>> devMap = EntryResult.parseEntryListMap(data, "ip");
        for (Map.Entry<String, List<Map<String, Object>>> e : devMap.entrySet()) {
            Map<String, Object> dev = new HashMap<>();
            dev.put("type", null);
            dev.put("name", e.getKey());
            dev.put("ip", e.getKey());
            dev.put("taskId", task.getId());
            dev.put("status", 2);
            dev.put("regionSid", Integer.valueOf((user == null || user.getRegionSid() == null) ? 110000 : user.getRegionSid().intValue()));
            dev.put("regionCid", Integer.valueOf((user == null || user.getRegionCid() == null) ? 110101 : user.getRegionCid().intValue()));
            this.pwdMapper.insertTaskDevice(dev);
            Integer devid = ObjectUtil.getInt(dev.get("id"));
            List<Map<String, Object>> pwdList = new ArrayList<>();
            for (Map<String, Object> pwdHash : e.getValue()) {
                try {
                    String pwdType = ObjectUtil.getString(pwdHash.get("type"), "");
                    String hash = ObjectUtil.getString(pwdHash.get("hash"), "");
                    if ("oracle".equalsIgnoreCase(pwdType)) {
                        StringBuilder oracleSb = new StringBuilder();
                        for (String oraUser : ORACLE_USER.split("\\|")) {
                            oracleSb.append(oraUser).append(":").append(hash).append("\n");
                        }
                        String hash2 = oracleSb.toString();
                        File ufile = new File(Constant.TEMP_DIR, new StringBuilder(String.valueOf(System.nanoTime())).toString());
                        FileUtils.writeStringToFile(ufile, hash2, "UTF-8");
                        pwdList.addAll(execHash(pwddicFile.getAbsolutePath(), ufile.getAbsolutePath(), "Excel模板导入-" + pwdType, devid, "--format=oracle"));
                    } else if ("tomcat".equalsIgnoreCase(pwdType)) {
                        for (String password : hash.split("\n")) {
                            if (pwds.contains("\n" + password + "\n")) {
                                Map<String, Object> pmap = new HashMap<>();
                                pmap.put("password", password);
                                pmap.put("protocol", "Excel模板导入-" + pwdType);
                                pwdList.add(pmap);
                            }
                        }
                    } else if ("windows".equalsIgnoreCase(pwdType) || "mysql".equalsIgnoreCase(pwdType) || "sqlserver".equalsIgnoreCase(pwdType)) {
                        File ufile2 = new File(Constant.TEMP_DIR, new StringBuilder(String.valueOf(System.nanoTime())).toString());
                        FileUtils.writeStringToFile(ufile2, hash, "UTF-8");
                        pwdList.addAll(execHash(pwddicFile.getAbsolutePath(), ufile2.getAbsolutePath(), "Excel模板导入-" + pwdType, devid, null));
                    } else if ("jboss".equalsIgnoreCase(pwdType)) {
                        for (String pwd : hash.split("\n")) {
                            String password2 = JbossDecryptor.decode(pwd);
                            if (pwds.contains("\n" + password2 + "\n")) {
                                Map<String, Object> pmap2 = new HashMap<>();
                                pmap2.put("password", password2);
                                pmap2.put("protocol", "Excel模板导入-" + pwdType);
                                pwdList.add(pmap2);
                            }
                        }
                    } else {
                        for (String password3 : hash.split("\n")) {
                            if (pwds.contains("\n" + password3 + "\n")) {
                                Map<String, Object> pmap3 = new HashMap<>();
                                pmap3.put("password", password3);
                                pmap3.put("protocol", "Excel模板导入-" + pwdType);
                                pwdList.add(pmap3);
                            }
                        }
                    }
                } catch (Exception e2) {
                    this.LOG.error("", e2);
                }
            }
            if (pwdList != null && pwdList.size() > 0) {
                this.engineMapper.sysAddPwds1(devid, pwdList);
            }
        }
    }
}
